@@ -3,7 +3,7 @@ package docker
 import (
 	"context"
 	"encoding/json"
-	"io/ioutil"
+	"fmt"
 	"math/rand"
 	"os"
 	"path/filepath"
@@ -13,7 +13,6 @@ import (
 	"time"
 
 	sysdnotify "github.com/iguanesolutions/go-systemd/v5/notify"
-	"github.com/pkg/errors"
 
 	"github.com/rclone/rclone/cmd/mountlib"
 	"github.com/rclone/rclone/fs"
@@ -44,12 +43,12 @@ func NewDriver(ctx context.Context, root string, mntOpt *mountlib.Options, vfsOp
 	cacheDir := config.GetCacheDir()
 	err := file.MkdirAll(cacheDir, 0700)
 	if err != nil {
-		return nil, errors.Wrapf(err, "failed to create cache directory: %s", cacheDir)
+		return nil, fmt.Errorf("failed to create cache directory: %s: %w", cacheDir, err)
 	}
 
 	//err = file.MkdirAll(root, 0755)
 	if err != nil {
-		return nil, errors.Wrapf(err, "failed to create mount root: %s", root)
+		return nil, fmt.Errorf("failed to create mount root: %s: %w", root, err)
 	}
 
 	// setup driver state
@@ -72,7 +71,7 @@ func NewDriver(ctx context.Context, root string, mntOpt *mountlib.Options, vfsOp
 	// restore from saved state
 	if !forgetState {
 		if err = drv.restoreState(ctx); err != nil {
-			return nil, errors.Wrap(err, "failed to restore state")
+			return nil, fmt.Errorf("failed to restore state: %w", err)
 		}
 	}
 
@@ -89,7 +88,7 @@ func NewDriver(ctx context.Context, root string, mntOpt *mountlib.Options, vfsOp
 
 	// notify systemd
 	if err := sysdnotify.Ready(); err != nil {
-		return nil, errors.Wrap(err, "failed to notify systemd")
+		return nil, fmt.Errorf("failed to notify systemd: %w", err)
 	}
 
 	return drv, nil
@@ -323,26 +322,26 @@ func (drv *Driver) saveState() error {
 
 	data, err := json.Marshal(state)
 	if err != nil {
-		return errors.Wrap(err, "failed to marshal state")
+		return fmt.Errorf("failed to marshal state: %w", err)
 	}
 
 	ctx := context.Background()
 	retries := fs.GetConfig(ctx).LowLevelRetries
 	for i := 0; i <= retries; i++ {
-		err = ioutil.WriteFile(drv.statePath, data, 0600)
+		err = os.WriteFile(drv.statePath, data, 0600)
 		if err == nil {
 			return nil
 		}
 		time.Sleep(time.Duration(rand.Intn(100)) * time.Millisecond)
 	}
-	return errors.Wrap(err, "failed to save state")
+	return fmt.Errorf("failed to save state: %w", err)
 }
 
 // restoreState recreates volumes from saved driver state
 func (drv *Driver) restoreState(ctx context.Context) error {
 	fs.Debugf(nil, "Restore state from %s", drv.statePath)
 
-	data, err := ioutil.ReadFile(drv.statePath)
+	data, err := os.ReadFile(drv.statePath)
 	if os.IsNotExist(err) {
 		return nil
 	}
